@@ -55,49 +55,49 @@
 #' @param ... Other arguments passed to \link[rstan]{sampling}. For multi-core processing, you can use \code{cores = parallel::detectCores()}, or run \code{options(mc.cores = parallel::detectCores())} first.
 #' @details
 #' 
-#'  The Stan code for the ICAR component of the model and the BYM2 option is from Morris et al. (2019) with adjustments to enable non-binary weights and disconnected graph structures (see Freni-Sterrantino (2018) and Donegan (2021)).
+#'  The intrinsic conditional autoregressive (ICAR) model for spatial data was introduced by Besag et al. (1991). The Stan code for the ICAR component of the model and the BYM2 option is from Morris et al. (2019) with adjustments to enable non-binary weights and disconnected graph structures (see Freni-Sterrantino (2018) and Donegan (2021)).
 #'
 #' The exact specification depends on the `type` argument. 
 #'
 #' ### 'icar'
 #'
 #' For Poisson models for count data, y, the basic model specification (`type = "icar"`) is:
-#' ```
-#' y ~ Poisson(exp(offset + mu + phi))
-#' phi ~ ICAR(spatial_scale)
-#' spatial_scale ~ Gaussian(0, 1)
-#' ```
-#'  where `mu` contains an intercept and potentially covariates. The spatial trend, `phi`, has a mean of zero and a single scale parameter, `spatial_scale`.
+#' \deqn{
+#' y ~ Poisson(e^{O + \mu + \phi}) \\
+#' \phi \sim ICAR(\tau_s) \\
+#' \tau_s \sim Gauss(0, 1)
+#' }
+#'  where \eqn{\mu} contains an intercept and potentially covariates. The spatial trend \eqn{phi} has a mean of zero and a single scale parameter \eqn{\tau_s} (which user's will see printed as the parameter named `spatial_scale`).
 #' 
-#' The ICAR prior model is a CAR model that has a spatial autocorrelation parameter \code{car_alpha} equal to 1 (see \link[geostan]{stan_car}). Thus the ICAR prior places high probability on a smooth spatially (or temporally) varying mean. This is rarely sufficient to model the amount of variation present in social and health data.
+#' The ICAR prior model is a CAR model that has a spatial autocorrelation parameter \eqn{\rho} equal to 1 (see \link[geostan]{stan_car}). Thus the ICAR prior places high probability on a very smooth spatially (or temporally) varying mean. This is rarely sufficient to model the amount of variation present in social and health data.
 #'
 #' ### 'bym'
 #'
-#' Often, an observational-level random effect term, `theta`, is added to capture (heterogeneous or unstructured) deviations from `mu + phi`. The combined term is referred to as a convolution term:
-#' ```
-#'  convolution = phi + theta.
-#' ```
+#' Often, an observational-level random effect term, `theta`, is added to capture (heterogeneous or unstructured) deviations from \eqn{\mu + \phi}. The combined term is referred to as a convolution term:
+#' \eqn{
+#'  convolution = \phi + \theta.
+#' }
 #' This is known as the BYM model (Besag et al. 1991), and can be specified using `type = "bym"`:
-#' ```
-#' y ~ Poisson(exp(offset + mu + phi + theta))
-#' phi ~ ICAR(spatial_scale)
-#' theta ~ Gaussian(0, theta_scale)
-#' spatial_scale ~ Gaussian(0, 1)
-#' theta_scale ~ Gaussian(0, 1)
-#' ```
+#' \eqn{
+#' y \sim Poisson(e^{O + \mu + \phi + \theta}) \\
+#' \phi \sim ICAR(\tau_s) \\
+#' \theta \sim Gaussian(0, \tau_{ns})
+#' \tau_s \sim Gaussian(0, 1)
+#' \tau_{ns} \sim Gaussian(0, 1)
+#' }
 #'
 #' ### 'bym2'
 #' 
-#' Riebler et al. (2016) introduce a variation on the BYM model (`type = "bym2"`). This specification combines `phi` and `theta` using a mixing parameter, `rho`, that controls the proportion of the variation that is attributable to the spatially autocorrelated term, `phi`, rather than the spatially unstructured term, `theta`. The terms share a single scale parameter:
-#' ```
-#' convolution = [sqrt(rho/scale_factor) * phi_tilde + sqrt(1 - rho) * theta_tilde] * spatial_scale.
-#' phi_tilde ~ Gaussian(0, 1)
-#' theta_tilde ~ Gaussian(0, 1)
-#' spatial_scale ~ Gaussian(0, 1)
-#' ```
-#' The two `_tilde` terms are standard normal deviates, `rho` is restricted to values between zero and one, and `scale_factor` is a constant term provided by the user. By default, `scale_factor` is equal to one, so that it does nothing. Riebler et al. (2016) argue that the interpretation or meaning of the scale of the ICAR model depends on the graph structure, `C`. This implies that the same prior distribution assigned to the `spatial_scale` will differ in its implications if `C` is changed; in other words, the priors are not transportable across models, and models that use the same nominal prior actually have different priors assigned to `spatial_scale`.
+#' Riebler et al. (2016) introduce a variation on the BYM model (`type = "bym2"`). This specification combines \eqn{\phi} and \eqn{\theta} using a mixing parameter \eqn{\rho} that controls the proportion of the variation that is attributable to the spatially autocorrelated term \eqn{\phi} rather than the spatially unstructured term \eqn{\theta}. The terms share a single scale parameter:
+#' \deqn{
+#' convolution = [sqrt(\rho * scale_factor) * \tilde{\phi} + sqrt(1 - \rho)  \tilde{\theta}] * \tau_s \\
+#' \tilde{\phi} \sim Gaussian(0, 1) \\
+#' \tilde{\theta} \sim Gaussian(0, 1) \\
+#' \tau_s \sim Gaussian(0, 1)
+#' }
+#' The terms \eqn{\tilde{\phi}}, \eqn{\tilde{\theta}} are standard normal deviates, \eqn{\rho} is restricted to values between zero and one, and the 'scale_factor' is a constant term provided by the user. By default, the 'scale_factor' is equal to one, so that it does nothing. Riebler et al. (2016) argue that the interpretation or meaning of the scale of the ICAR model depends on the graph structure of the connectivity matrix \eqn{C}. This implies that the same prior distribution assigned to \eqn{\tau_s} will differ in its implications if \eqn{C} is changed; in other words, the priors are not transportable across models, and models that use the same nominal prior actually have different priors assigned to \eqn{\tau_s}.
 #'
-#' Borrowing `R` code from Morris (2017) and following Freni-Sterrantino et al. (2018), the following `R` code can be used to create the `scale_factor` for the BYM2 model (note, this requires the INLA R package), given a spatial adjacency matrix, C:
+#' Borrowing `R` code from Morris (2017) and following Freni-Sterrantino et al. (2018), the following `R` code can be used to create the 'scale_factor' for the BYM2 model (note, this requires the INLA R package), given a spatial adjacency matrix, \eqn{C}:
 #' ```
 #' ## create a list of data for stan_icar
 #' icar.data <- geostan::prep_icar_data(C)
@@ -114,7 +114,7 @@
 #'   scale_factor[j] <- scale_c(Cg) 
 #' }
 #' ```
-#' This code adjusts for 'islands' or areas with zero neighbors, and it also handles disconnected graph structures (see Donegan 2021). Following Freni-Sterrantino (2018), disconnected components of the graph structure are given their own intercept term; however, this value is added to `phi` automatically inside the Stan model. Therefore, the user never needs to make any adjustments for this term. (If you want to avoid complications from a disconnected graph structure, see \code{\link[geostan]{stan_car}}).
+#' This code adjusts for 'islands' or areas with zero neighbors, and it also handles disconnected graph structures (see Donegan 2021). Following Freni-Sterrantino (2018), disconnected components of the graph structure are given their own intercept term; however, this value is added to \eqn{\phi} automatically inside the Stan model. Therefore, the user never needs to make any adjustments for this term. (If you want to avoid complications from a disconnected graph structure, see \code{\link[geostan]{stan_car}}).
 #' 
 #' Note, the code above requires the `scale_c` function; it has package dependencies that are not included in `geostan`. To use `scale_c`, you have to load the following `R` function:
 #' ```
@@ -146,61 +146,76 @@
 #'}
 #' ```
 #'
-#'  ### Spatially lagged covariates (SLX)
+#' ### Spatially lagged covariates (SLX)
 #' 
-#' The `slx` argument is a convenience function for including SLX terms. For example,
+#' The `slx` argument is a convenience function for including SLX terms. For example, 
+#' \deqn{
+#'  y = W X \gamma + X \beta + \epsilon
+#' }
+#' where \eqn{W} is a row-standardized spatial weights matrix (see \link[geostan]{shape2mat}), \eqn{WX} is the mean neighboring value of \eqn{X}, and \eqn{\gamma} is a coefficient vector. This specifies a regression with spatially lagged covariates. SLX terms can specified by providing a formula to the \code{slx} argument:
 #' ```
-#' stan_glm(y ~ x1 + x2, slx = ~ x1, ...)
+#' stan_glm(y ~ x1 + x2, slx = ~ x1 + x2, \...),
 #' ```
-#' is a shortcut for
+#' which is a shortcut for
 #' ```
-#' stan_glm(y ~ I(W %*% x1) + x1 + x2, ...)
+#' stan_glm(y ~ I(W \%*\% x1) + I(W \%*\% x2) + x1 + x2, \...)
 #' ```
-#' where `W` is a row-standardized spatial weights matrix (see \code{\link[geostan]{shape2mat}}). SLX terms will always be *prepended* to the design matrix, as above, which is important to know when setting prior distributions for regression coefficients.
+#' SLX terms will always be *prepended* to the design matrix, as above, which is important to know when setting prior distributions for regression coefficients.
 #'
 #' For measurement error (ME) models, the SLX argument is the only way to include spatially lagged covariates since the SLX term needs to be re-calculated on each iteration of the MCMC algorithm.
 #' 
 #' ### Measurement error (ME) models
 #' 
-#' The ME models are designed for surveys with spatial sampling designs, such as the American Community Survey (ACS) estimates (Donegan et al. 2021; Donegan 2021). With estimates, `x`, and their standard errors, `se`, the ME models have one of the the following two specifications, depending on the user input:
-#' ```
-#' x ~ Gauss(x_true, se)
-#' x_true ~ MVGauss(mu, Sigma)
-#' Sigma = (I - rho * C)^(-1) M * tau^2
-#' mu ~ Gauss(0, 100)
-#' tau ~ student_t(10, 0, 40)
-#' rho ~ uniform(lower_bound, upper_bound)
-#' ```
-#' where the covariance matrix, `Sigma`, has the conditional autoregressive specification, and `tau` is the scale parameter. For non-spatial ME models, the following is used instead:
-#' ```
-#' x ~ Gauss(x_true, se)
-#' x_true ~ student_t(df, mu, sigma)
-#' df ~ gamma(3, 0.2)
-#' mu ~ Gauss(0, 100)
-#' sigma ~ student_t(10, 0, 40)
-#' ```
+#' The ME models are designed for surveys with spatial sampling designs, such as the American Community Survey (ACS) estimates. Given estimates \eqn{x}, their standard errors \eqn{s}, and the target quantity of interest (i.e., the unknown true value) \eqn{z}, the ME models have one of the the following two specifications, depending on the user input. If a spatial CAR model is specified, then:
+#' \deqn{
+#'  x \sim Gauss(z, s^2) \\
+#'  z \sim Gauss(\mu_z, \Sigma_z) \\
+#' \Sigma_z = (I - \rho C)^{-1} M \\
+#'  \mu_z \sim Gauss(0, 100) \\
+#'  \tau_z \sim Student(10, 0, 40), \tau > 0 \\
+#'  \rho_z \sim uniform(l, u)
+#'  }
+#' where \eqn{\Sigma} specifies a spatial conditional autoregressive model with scale parameter \eqn{\tau} (on the diagonal of \eqn{M}), and \eqn{l}, \eqn{u} are the lower and upper bounds that \eqn{\rho} is permitted to take (which is determined by the extreme eigenvalues of the spatial connectivity matrix \eqn{C}).
 #' 
-#' For strongly skewed variables, such census tract poverty rates, it can be advantageous to apply a logit transformation to `x_true` before applying the CAR or Student t prior model. When the `logit` argument is used, the model becomes:
-#' ```
-#' x ~ Gauss(x_true, se)
-#' logit(x_true) ~ MVGauss(mu, Sigma)
-#' ```
-#' and similar for the Student t model.
+#' For non-spatial ME models, the following is used instead:
+#' \deqn{
+#' x \sim Gauss(z, s^2) \\
+#' z \sim student(\nu_z, \mu_z, \sigma_z) \\
+#' \nu_z \sim gamma(3, 0.2) \\
+#' \mu_z \sim Gauss(0, 100) \\
+#' \sigma_z \sim student(10, 0, 40).
+#' }
+#' 
+#' For strongly skewed variables, such as census tract poverty rates, it can be advantageous to apply a logit transformation to \eqn{z} before applying the CAR or Student-t prior model. When the `logit` argument is used, the model becomes:
+#' \deqn{
+#' x \sim Gauss(z, s^2) \\
+#' logit(z) \sim Gauss(\mu_z, \Sigma_z) 
+#' ...
+#' }
+#' and similarly for the Student t model:
+#' \deqn{
+#' x \sim Gauss(z, s^2) \\
+#' logit(z) \sim student(\nu_z, \mu_z, \sigma_z) \\
+#' ...
+#' }
 #'
 #' ### Censored counts
 #'
 #' Vital statistics systems and disease surveillance programs typically suppress case counts when they are smaller than a specific threshold value. In such cases, the observation of a censored count is not the same as a missing value; instead, you are informed that the value is an integer somewhere between zero and the threshold value. For Poisson models (`family = poisson())`), you can use the `censor_point` argument to encode this information into your model. 
 #'
 #' Internally, `geostan` will keep the index values of each censored observation, and the index value of each of the fully observed outcome values. For all observed counts, the likelihood statement will be:
-#' ```
-#' p(y_i | data, model) = Poisson(y_i | fitted_i), 
-#' ```
-#' as usual. For each censored count, the likelihood statement will equal the cumulative Poisson distribution function for values zero through the censor point:
-#' ```
-#' p(y_j | data, model) = sum_{m=0}^censor_point Poisson( c_m | fitted_j),
-#' ```
+#' \deqn{
+#' p(y_i | data, model) = poisson(y_i | \mu_i), 
+#' }
+#' as usual, where \eqn{\mu_i} may include whatever spatial terms are present in the model.
+#'
+#' For each censored count, the likelihood statement will equal the cumulative Poisson distribution function for values zero through the censor point:
+#' \deqn{
+#' p(y_i | data, model) = \sum_{m=0}^{M} Poisson( m | \mu_i),
+#' }
+#' where \eqn{M} is the censor point and \eqn{\mu_i} again is the fitted value for the \eqn{i^{th}} observation.
 #' 
-#' For example, the US Centers for Disease Control and Prevention's CDC WONDER database censors all death counts between 0 and 9. To model CDC WONDER mortality data, you could provide `censor_point = 9` and then the likelihood statement for censored counts would equal the summation of the Poisson probability mass function over each integer ranging from zero through 9 (inclusive), conditional on the fitted values (i.e., all model paramters). See Donegan (2021) for additional discussion, references, and Stan code.
+#' For example, the US Centers for Disease Control and Prevention's CDC WONDER database censors all death counts between 0 and 9. To model CDC WONDER mortality data, you could provide `censor_point = 9` and then the likelihood statement for censored counts would equal the summation of the Poisson probability mass function over each integer ranging from zero through 9 (inclusive), conditional on the fitted values (i.e., all model parameters). See Donegan (2021) for additional discussion, references, and Stan code.
 #'
 #' 
 #' @return An object of class class \code{geostan_fit} (a list) containing: 
@@ -219,15 +234,15 @@
 #' \item{spatial}{A data frame with the name of the spatial parameter (\code{"phi"} if \code{type = "icar"} else \code{"convolution"}) and method (\code{toupper(type)}).}
 #' }
 #' 
-#' @author Connor Donegan, \email{Connor.Donegan@UTDallas.edu}
+#' @author Connor Donegan, \email{connor.donegan@gmail.com}
 #'
 #' @seealso \link[geostan]{shape2mat}, \link[geostan]{stan_car}, \link[geostan]{stan_esf}, \link[geostan]{stan_glm}, \link[geostan]{prep_icar_data}
 #' 
 #' @source
 #'
-#' Besag, J. (1974). Spatial interaction and the statistical analysis of lattice systems. Journal of the Royal Statistical Society: Series B (Methodological), 36(2), 192-225.
+#' Besag, J. (1974). Spatial interaction and the statistical analysis of lattice systems. *Journal of the Royal Statistical Society: Series B (Methodological)*, 36(2), 192-225.
 #'
-#' Besag, J., York, J., & Mollié, A. (1991). Bayesian image restoration, with two applications in spatial statistics. Annals of the institute of statistical mathematics, 43(1), 1-20.
+#' Besag, J., York, J., & Mollié, A. (1991). Bayesian image restoration, with two applications in spatial statistics. *Annals of the Institute of Statistical Mathematics*, 43(1), 1-20.
 #'
 #' Donegan, Connor. 2021. Flexible functions for ICAR, BYM, and BYM2 models in Stan. Code repository. <https://github.com/ConnorDonegan/Stan-IAR>
 #'
@@ -235,11 +250,11 @@
 #'
 #' Donegan, Connor (2021). Spatial conditional autoregressive models in Stan. *OSF Preprints*. \doi{10.31219/osf.io/3ey65}.
 #' 
-#' Freni-Sterrantino, Anna, Massimo Ventrucci, and Håvard Rue. 2018. A Note on Intrinsic Conditional Autoregressive Models for Disconnected Graphs. Spatial and Spatio-Temporal Epidemiology 26: 25–34.
+#' Freni-Sterrantino, Anna, Massimo Ventrucci, and Håvard Rue. 2018. A Note on Intrinsic Conditional Autoregressive Models for Disconnected Graphs. *Spatial and Spatio-Temporal Epidemiology*, 26: 25–34.
 #' 
-#' Morris, M., Wheeler-Martin, K., Simpson, D., Mooney, S. J., Gelman, A., & DiMaggio, C. (2019). Bayesian hierarchical spatial models: Implementing the Besag York Mollié model in stan. Spatial and spatio-temporal epidemiology, 31, 100301.
+#' Morris, M., Wheeler-Martin, K., Simpson, D., Mooney, S. J., Gelman, A., & DiMaggio, C. (2019). Bayesian hierarchical spatial models: Implementing the Besag York Mollié model in stan. *Spatial and spatio-temporal epidemiology*, 31, 100301.
 #'
-#' Riebler, A., Sorbye, S. H., Simpson, D., & Rue, H. (2016). An intuitive Bayesian spatial model for disease mapping that accounts for scaling. Statistical Methods in Medical Research, 25(4), 1145-1165.
+#' Riebler, A., Sorbye, S. H., Simpson, D., & Rue, H. (2016). An intuitive Bayesian spatial model for disease mapping that accounts for scaling. *Statistical Methods in Medical Research*, 25(4), 1145-1165.
 #'
 #' @examples
 #' \donttest{
@@ -416,7 +431,7 @@ stan_icar <- function(formula,
     standata$type <- match(type, c("icar", "bym", "bym2"))
     ## ICAR DATA [STOP] -------------    
     ## EMPTY PLACEHOLDERS
-    standata <- c(standata, empty_esf_data(n), empty_car_data())
+    standata <- c(standata, empty_esf_data(n), empty_car_data(), empty_sar_data(n))
     ## ME MODEL -------------  
     me.list <- make_me_data(ME, xraw)
     standata <- c(standata, me.list)  
